@@ -55,7 +55,7 @@ _is_shutting_down = False
 
 def set_up_logging() -> None:
     root = logging.getLogger()
-    handler = logging.StreamHandler()
+    handler = logging.StreamHandler(stream=sys.stdout)
     formatter = logging.Formatter('%(levelname)-8s %(name)-20s %(message)s')
     handler.setFormatter(formatter)
     root.addHandler(handler)
@@ -133,11 +133,14 @@ def _init_sentry(config: DipDupConfig) -> None:
     sentry_sdk.init(
         dsn=config.sentry.dsn,
         environment=config.sentry.environment,
+        server_name=config.sentry.server_name,
+        release=config.sentry.release or __version__,
         integrations=integrations,
-        release=__version__,
         attach_stacktrace=attach_stacktrace,
         before_send=_sentry_before_send,
     )
+    sentry_sdk.set_tag('dipdup_version', __version__)
+    sentry_sdk.set_tag('dipdup_package', config.package)
 
 
 async def _check_version() -> None:
@@ -275,8 +278,6 @@ async def run(
         _logger.warning('`--metadata-interface` %s', warn_text)
         config.advanced.metadata_interface |= metadata_interface
 
-    set_decimal_context(config.package)
-
     dipdup = DipDup(config)
     await dipdup.run()
 
@@ -422,8 +423,6 @@ async def hasura(ctx) -> None:
 async def hasura_configure(ctx, force: bool) -> None:
     """Configure Hasura GraphQL Engine to use with DipDup."""
     config: DipDupConfig = ctx.obj.config
-    url = config.database.connection_string
-    models = f'{config.package}.models'
     if not config.hasura:
         raise ConfigurationError('`hasura` config section is empty')
     hasura_gateway = HasuraGateway(
@@ -432,9 +431,17 @@ async def hasura_configure(ctx, force: bool) -> None:
         database_config=cast(PostgresDatabaseConfig, config.database),
     )
 
-    async with tortoise_wrapper(url, models):
-        async with hasura_gateway:
-            await hasura_gateway.configure(force)
+    async with AsyncExitStack() as stack:
+        await stack.enter_async_context(
+            tortoise_wrapper(
+                url=config.database.connection_string,
+                models=config.package,
+                timeout=config.database.connection_timeout,
+            )
+        )
+        await stack.enter_async_context(hasura_gateway)
+
+        await hasura_gateway.configure(force)
 
 
 @cli.group()
