@@ -91,10 +91,19 @@ class SqliteDatabaseConfig:
     def schema_name(self) -> str:
         return 'public'
 
-    @cached_property
+    @property
     def connection_string(self) -> str:
         return f'{self.kind}://{self.path}'
 
+    @property
+    def immune_tables(self) -> Set[str]:
+        return set()
+
+    @property
+    def connection_timeout(self) -> int:
+        # NOTE: Fail immediately
+        return 1
+
 
 @dataclass
 class PostgresDatabaseConfig:
@@ -117,7 +126,7 @@ class PostgresDatabaseConfig:
     database: str = DEFAULT_POSTGRES_DATABASE
     port: int = DEFAULT_POSTGRES_PORT
     schema_name: str = DEFAULT_POSTGRES_SCHEMA
-    password: str = ''
+    password: str = field(default='', repr=False)
     immune_tables: Tuple[str, ...] = field(default_factory=tuple)
     connection_timeout: int = 60
 
@@ -1014,7 +1023,7 @@ class HasuraConfig:
     """
 
     url: str
-    admin_secret: Optional[str] = None
+    admin_secret: Optional[str] = field(default=None, repr=False)
     create_source: bool = False
     source: str = 'default'
     select_limit: int = 100
@@ -1076,12 +1085,16 @@ class SentryConfig:
     """Config for Sentry integration.
 
     :param dsn: DSN of the Sentry instance
-    :param environment: Environment to report to Sentry (informational only)
+    :param environment: Environment (defaults to `production`)
+    :param server_name: Server name (defaults to hostname)
+    :param release: Release version (defaults to DipDup version)
     :param debug: Catch warning messages and more context
     """
 
     dsn: str
     environment: Optional[str] = None
+    server_name: Optional[str] = None
+    release: Optional[str] = None
     debug: bool = False
 
 
@@ -1265,7 +1278,7 @@ class DipDupConfig:
         """Whether all indexes have `last_level` field set"""
         syncable_indexes = tuple(c for c in self.indexes.values() if not isinstance(c, HeadIndexConfig))
         oneshot_indexes = tuple(c for c in syncable_indexes if c.last_level)
-        if len(oneshot_indexes) == len(syncable_indexes):
+        if len(oneshot_indexes) == len(syncable_indexes) > 0:
             return True
         return False
 
